@@ -3,7 +3,6 @@ use std::{any, future::Future, io, pin::Pin};
 
 use futures_lite::future::FutureExt;
 use futures_lite::io::{AsyncRead, AsyncWrite};
-use glommio::Task;
 use ntex_bytes::{Buf, BufMut, BytesVec};
 use ntex_io::{
     types, Handle, IoStream, ReadContext, ReadStatus, WriteContext, WriteStatus,
@@ -14,16 +13,16 @@ use crate::net_impl::{TcpStream, UnixStream};
 
 impl IoStream for TcpStream {
     fn start(self, read: ReadContext, write: WriteContext) -> Option<Box<dyn Handle>> {
-        Task::local(ReadTask::new(self.clone(), read)).detach();
-        Task::local(WriteTask::new(self.clone(), write)).detach();
+        glommio::spawn_local(ReadTask::new(self.clone(), read)).detach();
+        glommio::spawn_local(WriteTask::new(self.clone(), write)).detach();
         Some(Box::new(self))
     }
 }
 
 impl IoStream for UnixStream {
     fn start(self, read: ReadContext, write: WriteContext) -> Option<Box<dyn Handle>> {
-        Task::local(UnixReadTask::new(self.clone(), read)).detach();
-        Task::local(UnixWriteTask::new(self, write)).detach();
+        glommio::spawn_local(UnixReadTask::new(self.clone(), read)).detach();
+        glommio::spawn_local(UnixWriteTask::new(self, write)).detach();
         None
     }
 }
